@@ -5,7 +5,7 @@
 """
 from time import sleep
 
-from .common import _location_in_viewport
+from .common import location_in_viewport
 from .keys import _modifierBit, _keyDescriptionForString
 
 
@@ -30,21 +30,34 @@ class ActionChains:
         :param offset_y: 偏移量y
         :return: self
         """
+        is_loc = False
         if isinstance(ele_or_loc, (tuple, list)):
+            is_loc = True
             lx = ele_or_loc[0] + offset_x
             ly = ele_or_loc[1] + offset_y
         elif isinstance(ele_or_loc, str) or 'ChromiumElement' in str(type(ele_or_loc)):
             ele_or_loc = self.page(ele_or_loc)
+            self.page.scroll_to_see(ele_or_loc)
             x, y = ele_or_loc.location if offset_x or offset_y else ele_or_loc.midpoint
             lx = x + offset_x
             ly = y + offset_y
         else:
             raise TypeError('ele_or_loc参数只能接受坐标(x, y)或ChromiumElement对象。')
 
-        if not _location_in_viewport(self.page, lx, ly):
-            self.page.scroll.to_location(lx, ly)
+        if not location_in_viewport(self.page, lx, ly):
+            # 把坐标滚动到页面中间
+            clientWidth = self.page.run_js('return document.body.clientWidth;')
+            clientHeight = self.page.run_js('return document.body.clientHeight;')
+            self.page.scroll.to_location(lx - clientWidth // 2, ly - clientHeight // 2)
+
+        # # 这样设计为了应付那些不随滚动条滚动的元素
+        if is_loc:
+            cx, cy = location_to_client(self.page, lx, ly)
+        else:
+            x, y = ele_or_loc.client_location if offset_x or offset_y else ele_or_loc.client_midpoint
+            cx = x + offset_x
+            cy = y + offset_y
 
-        cx, cy = location_to_client(self.page, lx, ly)
         self._dr.Input.dispatchMouseEvent(type='mouseMoved', x=cx, y=cy, modifiers=self.modifier)
         self.curr_x = cx
         self.curr_y = cy
@@ -183,19 +196,31 @@ class ActionChains:
         return self
 
     def up(self, pixel):
-        """鼠标向上移动若干像素"""
+        """鼠标向上移动若干像素            \n
+        :param pixel: 鼠标移动的像素值
+        :return: self
+        """
         return self.move(0, -pixel)
 
     def down(self, pixel):
-        """鼠标向下移动若干像素"""
+        """鼠标向下移动若干像素           \n
+        :param pixel: 鼠标移动的像素值
+        :return: self
+        """
         return self.move(0, pixel)
 
     def left(self, pixel):
-        """鼠标向左移动若干像素"""
+        """鼠标向左移动若干像素           \n
+        :param pixel: 鼠标移动的像素值
+        :return: self
+        """
         return self.move(-pixel, 0)
 
     def right(self, pixel):
-        """鼠标向右移动若干像素"""
+        """鼠标向右移动若干像素           \n
+        :param pixel: 鼠标移动的像素值
+        :return: self
+        """
         return self.move(pixel, 0)
 
     def key_down(self, key):
@@ -266,4 +291,4 @@ def location_to_client(page, lx, ly):
     """绝对坐标转换为视口坐标"""
     scroll_x = page.run_js('return document.documentElement.scrollLeft;')
     scroll_y = page.run_js('return document.documentElement.scrollTop;')
-    return lx + scroll_x, ly + scroll_y
+    return lx - scroll_x, ly - scroll_y
