@@ -10,7 +10,7 @@ from requests import Session
 
 from .base import BasePage
 from .chromium_element import ChromiumElementWaiter, ChromiumScroll, ChromiumElement, run_js, make_chromium_ele
-from .common import get_loc
+from .common import get_loc, offset_scroll
 from .config import cookies_to_tuple
 from .session_element import make_session_ele
 from .chromium_driver import ChromiumDriver
@@ -25,13 +25,14 @@ class ChromiumBase(BasePage):
         :param tab_id: 要控制的标签页id，不指定默认为激活的
         :param timeout: 超时时间
         """
-        super().__init__(timeout)
         self._is_loading = None
         self._root_id = None
         self._debug = False
         self._debug_recorder = None
         self.timeouts = Timeout(self)
         self._connect_browser(address, tab_id)
+        timeout = timeout if timeout is not None else self.timeouts.implicit
+        super().__init__(timeout)
 
     def _connect_browser(self, addr_driver_opts=None, tab_id=None):
         """连接浏览器，在第一次时运行                                    \n
@@ -280,7 +281,7 @@ class ChromiumBase(BasePage):
         :return: None
         """
         if implicit is not None:
-            self.timeout = implicit
+            self.timeouts.implicit = implicit
 
         if page_load is not None:
             self.timeouts.page_load = page_load
@@ -295,6 +296,7 @@ class ChromiumBase(BasePage):
         :param args: 参数，按顺序在js文本中对应argument[0]、argument[1]...
         :return: 运行的结果
         """
+        self._to_d_mode()
         return run_js(self, script, as_expr, self.timeouts.script, args)
 
     def run_async_js(self, script, as_expr=False, *args):
@@ -304,6 +306,7 @@ class ChromiumBase(BasePage):
         :param args: 参数，按顺序在js文本中对应argument[0]、argument[1]...
         :return: None
         """
+        self._to_d_mode()
         from threading import Thread
         Thread(target=run_js, args=(self, script, as_expr, self.timeouts.script, args)).start()
 
@@ -395,7 +398,7 @@ class ChromiumBase(BasePage):
         """
         return make_session_ele(self, loc_or_ele)
 
-    def s_eles(self, loc_or_str=None):
+    def s_eles(self, loc_or_str):
         """查找所有符合条件的元素以SessionElement列表形式返回                       \n
         :param loc_or_str: 元素的定位信息，可以是loc元组，或查询字符串
         :return: SessionElement对象组成的列表
@@ -459,12 +462,16 @@ class ChromiumBase(BasePage):
         :param loc_or_ele: 元素的定位信息，可以是loc元组，或查询字符串（详见ele函数注释）
         :return: None
         """
-        node_id = self.ele(loc_or_ele).node_id
+        ele = self.ele(loc_or_ele)
+        node_id = ele.node_id
         try:
             self._wait_driver.DOM.scrollIntoViewIfNeeded(nodeId=node_id)
         except Exception:
             self.ele(loc_or_ele).run_js("this.scrollIntoView();")
 
+        if not ele.is_in_viewport:
+            offset_scroll(ele, 0, 0)
+
     def refresh(self, ignore_cache=False):
         """刷新当前页面                      \n
         :param ignore_cache: 是否忽略缓存
@@ -572,7 +579,8 @@ class ChromiumBase(BasePage):
         :param value: 项的值，设置为False时，删除该项
         :return: None
         """
-        js = f'sessionStorage.removeItem("{item}");' if item is False else f'sessionStorage.setItem("{item}","{value}");'
+        js = f'sessionStorage.removeItem("{item}");' if item is False \
+            else f'sessionStorage.setItem("{item}","{value}");'
         return self.run_js(js, as_expr=True)
 
     def set_local_storage(self, item, value):
@@ -645,19 +653,20 @@ class ChromiumBase(BasePage):
 
         return True
 
+    def _to_d_mode(self):
+        """用于使WebPage切换到d模式"""
+        return self._driver
+
 
 class Timeout(object):
     """用于保存d模式timeout信息的类"""
 
     def __init__(self, page):
-        self.page = page
+        self._page = page
+        self.implicit = 10
         self.page_load = 30
         self.script = 30
 
-    @property
-    def implicit(self):
-        return self.page.timeout
-
 
 class PageLoadStrategy(object):
     """用于设置页面加载策略的类"""
