@@ -64,7 +64,7 @@ class ChromiumFrame(ChromiumBase):
 
         try:
             self._tab_obj.DOM.describeNode(nodeId=self.node_id)
-        except:
+        except Exception:
             self._reload()
             sleep(2)
 
@@ -359,6 +359,15 @@ class ChromiumFrame(ChromiumBase):
         self._check_ok()
         return self.frame_ele.befores(filter_loc, timeout)
 
+    def afters(self, filter_loc='', timeout=None):
+        """返回当前元素后面符合条件的全部兄弟元素或节点组成的列表，可用查询语法筛选。查找范围不限兄弟元素，而是整个DOM文档        \n
+        :param filter_loc: 用于筛选元素的查询语法
+        :param timeout: 查找元素的超时时间
+        :return: 本元素前面的元素或节点组成的列表
+        """
+        self._check_ok()
+        return self.frame_ele.afters(filter_loc, timeout)
+
     def _ele(self, loc_or_ele, timeout=None, single=True, relative=False):
         """在frame内查找单个元素                         \n
         :param loc_or_ele: 定位符或元素对象
