@@ -42,7 +42,6 @@ class OptionsManager(object):
         """返回paths设置"""
         if self._paths is None:
             self._paths = self.get_option('paths')
-
         return self._paths
 
     @property
@@ -50,7 +49,6 @@ class OptionsManager(object):
         """返回chrome设置"""
         if self._chrome_options is None:
             self._chrome_options = self.get_option('chrome_options')
-
         return self._chrome_options
 
     @property
@@ -58,7 +56,6 @@ class OptionsManager(object):
         """返回session设置"""
         if self._session_options is None:
             self._session_options = self.get_option('session_options')
-
         return self._session_options
 
     def get_value(self, section, item):
@@ -151,6 +148,7 @@ class SessionOptions(object):
         self._stream = None
         self._trust_env = None
         self._max_redirects = None
+        self.timeout = 10
 
         if read_file:
             self.ini_path = ini_path or str(Path(__file__).parent / 'configs.ini')
@@ -193,6 +191,8 @@ class SessionOptions(object):
             if options_dict.get('max_redirects', None) is not None:
                 self._max_redirects = options_dict['max_redirects']
 
+            self.timeout = options_dict.get('timeout', 10)
+
     @property
     def headers(self):
         """返回headers设置信息"""
@@ -488,9 +488,6 @@ class DriverOptions(Options):
             self.timeouts['pageLoad'] *= 1000
             self.timeouts['script'] *= 1000
 
-        if '--no-sandbox' not in self._arguments:
-            self._arguments.append('--no-sandbox')
-
     @property
     def driver_path(self):
         """chromedriver文件路径"""
@@ -498,6 +495,11 @@ class DriverOptions(Options):
 
     @property
     def chrome_path(self):
+        """浏览器启动文件路径"""
+        return self.browser_path
+
+    @property
+    def browser_path(self):
         """浏览器启动文件路径"""
         return self.binary_location or 'chrome'
 
@@ -718,11 +720,12 @@ class DriverOptions(Options):
         self.page_load_strategy = value.lower()
         return self
 
-    def set_paths(self, driver_path=None, chrome_path=None, local_port=None, debugger_address=None, download_path=None,
-                  user_data_path=None, cache_path=None):
+    def set_paths(self, driver_path=None, chrome_path=None, browser_path=None, local_port=None,
+                  debugger_address=None, download_path=None, user_data_path=None, cache_path=None):
         """快捷的路径设置函数                                             \n
         :param driver_path: chromedriver.exe路径
         :param chrome_path: chrome.exe路径
+        :param browser_path: 浏览器可执行文件路径
         :param local_port: 本地端口号
         :param debugger_address: 调试浏览器地址，例：127.0.0.1:9222
         :param download_path: 下载文件路径
@@ -736,6 +739,9 @@ class DriverOptions(Options):
         if chrome_path is not None:
             self.binary_location = str(chrome_path)
 
+        if browser_path is not None:
+            self.binary_location = str(browser_path)
+
         if local_port is not None:
             self.debugger_address = '' if local_port == '' else f'127.0.0.1:{local_port}'
 
