@@ -67,12 +67,6 @@ class DriverPage(BasePage):
         """
         retry, interval = self._before_connect(url, retry, interval)
         self._url_available = self._d_connect(self._url, times=retry, interval=interval, show_errmsg=show_errmsg)
-
-        try:
-            self._driver.execute_script('Object.defineProperty(navigator,"webdriver",{get:() => undefined,});')
-        except Exception:
-            pass
-
         return self._url_available
 
     def ele(self, loc_or_ele, timeout=None):
@@ -101,7 +95,7 @@ class DriverPage(BasePage):
         else:
             return make_session_ele(self, loc_or_ele)
 
-    def s_eles(self, loc_or_str=None):
+    def s_eles(self, loc_or_str):
         """查找所有符合条件的元素以SessionElement列表形式返回                       \n
         :param loc_or_str: 元素的定位信息，可以是loc元组，或查询字符串
         :return: SessionElement对象组成的列表
