@@ -80,37 +80,37 @@ class SessionElement(DrissionElement):
         """
         return super().parent(level_or_loc)
 
-    def prev(self, index=1, filter_loc='', timeout=0):
+    def prev(self, filter_loc='', index=1, timeout=0):
         """返回前面的一个兄弟元素，可用查询语法筛选，可指定返回筛选结果的第几个        \n
-        :param index: 前面第几个查询结果元素
         :param filter_loc: 用于筛选元素的查询语法
+        :param index: 前面第几个查询结果元素
         :param timeout: 查找元素的超时时间
         :return: 兄弟元素
         """
         return super().prev(index, filter_loc, timeout)
 
-    def next(self, index=1, filter_loc='', timeout=0):
+    def next(self, filter_loc='', index=1, timeout=0):
         """返回后面的一个兄弟元素，可用查询语法筛选，可指定返回筛选结果的第几个        \n
-        :param index: 后面第几个查询结果元素
         :param filter_loc: 用于筛选元素的查询语法
+        :param index: 后面第几个查询结果元素
         :param timeout: 查找元素的超时时间
         :return: 兄弟元素
         """
         return super().next(index, filter_loc, timeout)
 
-    def before(self, index=1, filter_loc='', timeout=None):
+    def before(self, filter_loc='', index=1, timeout=None):
         """返回前面的一个兄弟元素，可用查询语法筛选，可指定返回筛选结果的第几个        \n
-        :param index: 前面第几个查询结果元素
         :param filter_loc: 用于筛选元素的查询语法
+        :param index: 前面第几个查询结果元素
         :param timeout: 查找元素的超时时间
         :return: 本元素前面的某个元素或节点
         """
         return super().before(index, filter_loc, timeout)
 
-    def after(self, index=1, filter_loc='', timeout=None):
+    def after(self, filter_loc='', index=1, timeout=None):
         """返回后面的一个兄弟元素，可用查询语法筛选，可指定返回筛选结果的第几个        \n
-        :param index: 后面第几个查询结果元素
         :param filter_loc: 用于筛选元素的查询语法
+        :param index: 后面第几个查询结果元素
         :param timeout: 查找元素的超时时间
         :return: 本元素后面的某个元素或节点
         """
@@ -204,7 +204,7 @@ class SessionElement(DrissionElement):
         """
         return self._ele(loc_or_str)
 
-    def s_eles(self, loc_or_str=None):
+    def s_eles(self, loc_or_str):
         """返回当前元素下级所有符合条件的子元素、属性或节点文本                       \n
         :param loc_or_str: 元素的定位信息，可以是loc元组，或查询字符串
         :return: SessionElement对象或属性、文本组成的列表
