@@ -20,14 +20,16 @@ from .session_element import SessionElement, make_session_ele
 class SessionPage(BasePage):
     """SessionPage封装了页面操作的常用功能，使用requests来获取、解析网页"""
 
-    def __init__(self, session_or_options=None, timeout=10):
+    def __init__(self, session_or_options=None, timeout=None):
         """初始化                                                     \n
         :param session_or_options: Session对象或SessionOptions对象
-        :param timeout: 连接超时时间
+        :param timeout: 连接超时时间，为None时从ini文件读取
         """
-        super().__init__(timeout)
         self._response = None
+        self.timeout = 10
         self._create_session(session_or_options)
+        timeout = timeout if timeout is not None else self.timeout
+        super().__init__(timeout)
 
     def _create_session(self, Session_or_Options):
         """创建内建Session对象
@@ -37,6 +39,7 @@ class SessionPage(BasePage):
         if Session_or_Options is None or isinstance(Session_or_Options, SessionOptions):
             options = Session_or_Options or SessionOptions()
             self._set_session(options.as_dict())
+            self.timeout = options.timeout
         elif isinstance(Session_or_Options, Session):
             self._session = Session_or_Options
 
@@ -145,7 +148,7 @@ class SessionPage(BasePage):
         """
         return make_session_ele(self.html) if loc_or_ele is None else self._ele(loc_or_ele)
 
-    def s_eles(self, loc_or_str=None):
+    def s_eles(self, loc_or_str):
         """返回页面中符合条件的所有元素、属性或节点文本                              \n
         :param loc_or_str: 元素的定位信息，可以是元素对象，loc元组，或查询字符串
         :return: SessionElement对象或属性、文本
@@ -318,7 +321,7 @@ def set_charset(response) -> Response:
     """设置Response对象的编码"""
     # 在headers中获取编码
     content_type = response.headers.get('content-type', '').lower()
-    charset = search(r'charset[=: ]*(.*)?[;]', content_type)
+    charset = search(r'charset[=: ]*(.*)?;', content_type)
 
     if charset:
         response.encoding = charset.group(1)
